@@ -76,10 +76,13 @@ def assemble(lines):
                     # Two params
                     elif instruction in ['jmp', 'ldi', 'sti', 'stg',
                                          'cmp', 'mv', 'neg', 'not']:
-                        _, a = tokens.next()
-                        maybe_label, b = tokens.next()
+                        maybe_label, a = tokens.next()
                         if maybe_label == 'label':
-                            b = labels[b]
+                            b = labels[a]
+                            a = 0
+                            print instruction, a, b
+                        else:
+                            _, b = tokens.next()
                         instruction = instruction_map[value.capitalize()](a, b)
 
                     # One param
